@@ -8,4 +8,6 @@ from . import menus
 from . import pixmaps
 from . import styling
 from . import widgets
-from . import windows
\ No newline at end of file
+from . import windows
+from . import request
+from . import sizing
